#include "quicktime.h"

int quicktime_init_codecs(quicktime_video_map_t *vtrack)
{
	char *compressor = vtrack->track->mdia.minf.stbl.stsd.table[0].format;
	if(quicktime_match_32(compressor, QUICKTIME_RAW))
		quicktime_init_codec_raw(vtrack);
	if(quicktime_match_32(compressor, QUICKTIME_JPEG))
		quicktime_init_codec_jpeg(vtrack);
	if(quicktime_match_32(compressor, QUICKTIME_YUV2))
		quicktime_init_codec_yuv2(vtrack);

	return 0;
}

int quicktime_delete_codecs(quicktime_video_map_t *vtrack)
{
	char *compressor = vtrack->track->mdia.minf.stbl.stsd.table[0].format;
	if(quicktime_match_32(compressor, QUICKTIME_RAW))
		quicktime_delete_codec_raw(vtrack);
	if(quicktime_match_32(compressor, QUICKTIME_JPEG))
		quicktime_delete_codec_jpeg(vtrack);
	if(quicktime_match_32(compressor, QUICKTIME_YUV2))
		quicktime_delete_codec_yuv2(vtrack);

	return 0;
}

int quicktime_supported_video(quicktime_t *file, int track)
{
	char *compressor = quicktime_video_compressor(file, track);

	if(quicktime_match_32(compressor, QUICKTIME_RAW)) return 1;
	if(quicktime_match_32(compressor, QUICKTIME_JPEG)) return 1;
	if(quicktime_match_32(compressor, QUICKTIME_YUV2)) return 1;

	return 0;
}

int quicktime_decode_video(quicktime_t *file, unsigned char **row_pointers, int track)
{
	char *compressor = quicktime_video_compressor(file, track);
	int result = 0;

// test ram cache boundary
	if(file->vtracks[track].frames_cached &&
		file->vtracks[track].current_position >= file->vtracks[track].frames_cached) result = 1;

	if(!result)
	{
		if(quicktime_match_32(compressor, QUICKTIME_RAW))
			result = quicktime_decode_raw(file, row_pointers, track);
		else
		if(quicktime_match_32(compressor, QUICKTIME_JPEG))
			result = quicktime_decode_jpeg(file, row_pointers, track);
		else
		if(quicktime_match_32(compressor, QUICKTIME_YUV2))
			result = quicktime_decode_yuv2(file, row_pointers, track);
		else
			result = 1;
	}

	file->vtracks[track].current_position++;

	return result;
}

int quicktime_encode_video(quicktime_t *file, unsigned char **row_pointers, int track)
{
	char *compressor = quicktime_video_compressor(file, track);
	int result = 0;

	if(quicktime_match_32(compressor, QUICKTIME_RAW))
		result = quicktime_encode_raw(file, row_pointers, track);
	else
	if(quicktime_match_32(compressor, QUICKTIME_JPEG))
		result = quicktime_encode_jpeg(file, row_pointers, track);
	else
	if(quicktime_match_32(compressor, QUICKTIME_YUV2))
		result = quicktime_encode_yuv2(file, row_pointers, track);
	else
		result = 1;

	file->vtracks[track].current_position++;

	return result;
}

